@@ -1,7 +1,6 @@
 import random
 import re
 import traceback
-from functools import partial
 from importlib import import_module, metadata
 from os.path import dirname, basename, join
 from pathlib import Path
@@ -10,9 +9,10 @@ from typing import Optional, Union, Callable, Iterable, Dict, Tuple, List, Typed
 
 import ptyx.randfunc as randfunc
 from ptyx import __version__, __api__
-from ptyx.config import param, sympy
+from ptyx.config import param, SYMPY_AVAILABLE
 from ptyx.context import GLOBAL_CONTEXT
-from ptyx.printers import sympy2latex
+
+# from ptyx.printers import sympy2latex
 from ptyx.syntax_tree import Node, SyntaxTreeGenerator, Tag, TagSyntax
 from ptyx.utilities import advanced_split, numbers_to_floats, _float_me_if_you_can
 
@@ -89,10 +89,17 @@ class LatexGenerator:
         self.backups = []
         # When write() is called from inside a #PYTHON ... #END code block,
         # its argument may contain pTyX code needing parsing.
-        self.context["write"] = partial(self.write, parse=True)
+        # Write argument used to be parsed by default, but this was rarely needed
+        # and led to very surprising behaviour sometimes from user perspective.
+        # Now, one should use write(..., parse=True) if needed, which is much saner.
+        self.context["write"] = self.write
         # Internal flags
         self.flags = {}
 
+    def reset(self):
+        """To overwrite."""
+        self.clear()
+
     def set_new_context(self, context: Optional[Dict] = None):
         """Set a new context of evaluation for code, except for PTYX_LATEX value."""
         if context is None:
@@ -631,7 +638,7 @@ class LatexGenerator:
             return ""
         sympy_code = flags.get("sympy", param["sympy_is_default"])
 
-        if sympy_code and sympy is None:
+        if sympy_code and not SYMPY_AVAILABLE:
             raise ImportError("sympy library not found.")
 
         varname = ""
@@ -649,7 +656,9 @@ class LatexGenerator:
             varname = "_"
         if " if " in code and " else " not in code:
             code += " else ''"
-        if sympy is not None and sympy_code:
+        if SYMPY_AVAILABLE and sympy_code:
+            import sympy
+
             try:
                 result = sympy.sympify(code, locals=context)
                 if isinstance(result, str):
@@ -657,13 +666,13 @@ class LatexGenerator:
             except (sympy.SympifyError, AttributeError):
                 # sympy.sympify() can't parse attributes and methods inside
                 # code for now (AttributeError is raised then).
-                sympy_code = False
+                result = eval(code, context)
                 print("Warning: sympy can't parse %s. " "Switching to standard evaluation mode." % repr(code))
             except Exception:
                 # print sorted(context.keys())
                 print("Uncatched error when evaluating %s" % repr(code))
                 raise
-        if not sympy_code:
+        else:
             result = eval(code, context)
         result = context["_"] = self._apply_flag(result)
         i = varname.find("[")
@@ -700,6 +709,8 @@ class LatexGenerator:
             return ""
 
         if sympy_code and not flags.get("str"):
+            from ptyx.printers import sympy2latex
+
             latex = sympy2latex(result, **flags)
         else:
             latex = str(result)
@@ -753,7 +764,7 @@ class LatexGenerator:
 
         if "round" in flags:
             try:
-                if sympy:
+                if SYMPY_AVAILABLE:
                     round_result = numbers_to_floats(result, ndigits=flags["round"])
                 else:
                     round_result = round(result, flags["round"])
@@ -764,7 +775,10 @@ class LatexGenerator:
                 print("".join(self.context["PTYX_LATEX"])[-100:])
                 print("-----")
                 raise
-            if sympy and isinstance(result, sympy.Basic):
+            if SYMPY_AVAILABLE:
+                import sympy
+            # noinspection PyUnboundLocalVariable
+            if SYMPY_AVAILABLE and isinstance(result, sympy.Basic):
                 flags["result_is_exact"] = {_float_me_if_you_can(elt) for elt in result.atoms()} == {
                     _float_me_if_you_can(elt) for elt in round_result.atoms()
                 }
@@ -815,6 +829,7 @@ class Compiler:
         self._state: State = {}
         # Make SyntaxTreeGenerator context free ?
         self.syntax_tree_generator.reset()
+        self.latex_generator.reset()
 
     def read_code(self, code: str) -> None:
         """Feed compiler with given code."""
@@ -939,6 +954,14 @@ class Compiler:
             print(f"Warning: multiple #SEED found, only last one will be used: {value}.")
         return code, value
 
+    @staticmethod
+    def _assert_no_comment(code: str) -> None:
+        """AssertionError raised if comments remain."""
+        comments = any((" # " in code, "\n# " in code, code.startswith("# ")))
+        if comments:
+            print(code)
+        assert not comments, "There should be no remaining comment. Maybe a problem with an extension ?"
+
     def preparse(self) -> None:
         code = self._state.get("input")
         if code is None:
@@ -947,19 +970,21 @@ class Compiler:
         # Remove comments first, so one can comment a file inclusion for example.
         code = remove_comments(code)
         assert isinstance(code, str)
+        self._assert_no_comment(code)
         code = remove_comments(self._include_subfiles(code))
         self._state["after_include"] = code
         assert isinstance(code, str)
         code, extensions = self._call_extensions(code)
         code, seed = self._read_seed(code)
+        # Remove any comment that may have been generated by an extension.
+        code = remove_comments(code)
+        assert isinstance(code, str)
         self._state["plain_ptyx_code"] = code
         self._state["loaded_extensions"] = extensions
         # Set the seed used for pseudo-random numbers generation.
         # (The seed value is set in the ptyx file using special tag #SEED{}).
         self._state["seed"] = seed
-        assert " # " not in code, "Maybe a problem with an extension ?"
-        assert "\n# " not in code, "Maybe a problem with an extension ?"
-        assert not code.startswith("# "), "Maybe a problem with an extension ?"
+        self._assert_no_comment(code)
         assert "#INCLUDE{" not in code
         assert "#LOAD{" not in code
         assert "#SEED{" not in code
@@ -1019,13 +1044,30 @@ class Compiler:
             self.syntax_tree_generator.update_tags()
             self.latex_generator.parser.update_tags()
 
-    def parse(self, code: str, **context) -> str:
+    # TODO: change the signature of parse, to force use of `code` as a keyword argument.
+    # Note that this will involve rewriting a lot of tests in both ptyx and ptyx-mcq projects.
+    #   parse(self, *, code: str = None, path: Union[Path, str] = None, **context)
+
+    def parse(self, code: str = None, *, path: Union[Path, str] = None, **context) -> str:
         """Convert ptyx code to plain LaTeX in one shot.
 
         This is mainly used for testing (in unit tests or in interactive mode).
+
+        One may provide either directly the pTyX code, or the path of a pTyX file to be read.
+
+        If both `code` and `path` are provided, the compiler acts as if `code` was the content
+        of the pTyX file located at `path`.
         """
         self.reset()
-        self.read_code(code)
+        if path is None and code is None:
+            raise ValueError(
+                "You must provide either the pTyX code or the path to a pTyX file:\n"
+                'compiler.parse(code="...") or compiler.parse(path="/path/to/file.ptyx")'
+            )
+        if path is not None:
+            self.read_file(path)
+        if code is not None:
+            self.read_code(code)
         self.preparse()
         self.generate_syntax_tree()
         latex = self.get_latex(**context)
@@ -1043,6 +1085,10 @@ class Compiler:
     def file_path(self) -> Optional[Path]:
         return self._state["path"]
 
+    @property
+    def plain_ptyx_code(self) -> Optional[str]:
+        return self._state["plain_ptyx_code"]
+
     @property
     def loaded_extensions(self) -> List[str]:
         return list(self._state["loaded_extensions"].keys())
